import { useState } from 'react';
import { API_URL } from '../config';

function PostForm({ onPostCreated }) {
  const [text, setText] = useState('');
  const [image, setImage] = useState(null);
  const [preview, setPreview] = useState('');

  const handleSubmit = async (e) => {
    e.preventDefault();
    const formData = new FormData();
    if (text) formData.append('text', text);
    if (image) formData.append('image', image);

    try {
      const response = await fetch(`${API_URL}/posts/`, {
        method: 'POST',
        body: formData,
      });
      
      if (response.ok) {
        const data = await response.json();
        onPostCreated(data.vector);
        setText('');
        setImage(null);
        setPreview('');
      }
    } catch (error) {
      console.error('Post creation error:', error);
    }
  };

  const handleImageChange = (e) => {
    const file = e.target.files[0];
    if (file) {
      setImage(file);
      const reader = new FileReader();
      reader.onload = () => setPreview(reader.result);
      reader.readAsDataURL(file);
    }
  };

  return (
    <div className="post-form">
      <h2>Новый пост</h2>
      <form onSubmit={handleSubmit}>
        <textarea
          value={text}
          onChange={(e) => setText(e.target.value)}
          rows="4"
          placeholder="Текст поста"
        />
        <input type="file" onChange={handleImageChange} accept="image/*" />
        {preview && <img src={preview} className="preview-image" alt="Preview" />}
        <button type="submit">Отправить</button>
      </form>
    </div>
  );
}

export default PostForm;